import subprocess
import re
import os

class TestinfraLauncher:

    def __init__(self, yaml_loader):
        self.yaml_loader = yaml_loader

    def run_test(self, file_name, inventory, current_path):
        tests = self.yaml_loader.load(file_name)
        for test in tests:
            command = build_command(test, inventory, current_path)
            subprocess.run(command.split(' '))


def build_tests_path(roles, current_path):
    result = ''
    if isinstance(roles, str):
        return ' {}/roles/{}/tests'.format(current_path, roles)
    for role in roles:
        if isinstance(role, dict):
            if os.path.exists('{}/roles/{}/tests'.format(current_path, role['role'])):
                result += ' {}/roles/{}/tests'.format(current_path, role['role'])
        else:
            if os.path.exists('{}/roles/{}/tests'.format(current_path, role)):
                result += ' {}/roles/{}/tests'.format(current_path, role)
    return result


def build_command(test_content, inventory, current_path):
    hosts = build_hosts_list(test_content['hosts'])
    roles = test_content['roles']
    tests_path = build_tests_path(roles, current_path)
    return 'pytest --connection=ansible --ansible-inventory=' + inventory + ' --hosts=ansible://' + hosts + tests_path


def build_hosts_list(hosts):
    if isinstance(hosts, list):
        return ','.join(hosts)
    return re.sub(':', ',', hosts)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='ansible-tests',
    version='0.0.4',
    author="Tanguy Patte",
    url="https://github.com/TanguyPatte/ansible-tests.git",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=["*_tests_tests"]),
    install_requires=[
        'click',
        'pyyaml',
        'testinfra',
        'ansible'
    ],
    entry_points={
        'console_scripts': [
            'ansible-tests = ansible_tests.__main__:run',
        ],
    },
)



import click
from ansible_tests.yaml_loader import YamlLoader
from ansible_tests.testinfra_launcher import TestinfraLauncher
import os


@click.command("ansible-tests")
@click.option("--playbook", "-p", type=click.Path(exists=True, file_okay=True, resolve_path=True),
              help='Name of the playbook or tests description file', required=True)
@click.option("--inventory", "-i", type=click.Path(exists=True, file_okay=True, resolve_path=True),
              help='Name of the inventory', required=True)
def run(playbook, inventory):
    current_path = os.getcwd()
    TestinfraLauncher(YamlLoader()).run_test(playbook, inventory, current_path)


if __name__ == '__main__':
    run()
